__author__ = 'piyush'
print """Hedwig

Jab yahan se 50 kos door koi developer SOA me communication ke liye rota hai,
To uska TL kehta chup ho ja, hum Hedwig laga denge.

Hedwig is a highly extensible cross language set of libraries to implement reliable communication between services.
To achieve this, it uses the emitter-consumer model on top of AMQP.

Principles of Hedwig

Keep it simple and reliable.
Do not repeat yourself.
Trust the developers to do a good job.
There should be one good default to plug and play.
Explicit is better than implicit. (H/t Zen of Python, Tim Peters)
Safe implicit is better than nothing.
Allow for powerful configuration and extension.
Keep reusable implementation and business use cases separate.
Contribute the reusable implementation back to the community.
Reliability and usability beat everything.
"""
